@@ -6,12 +6,12 @@ from .utils import get_outprefix
 
 
 def get_preface_predict_cmd(
-    singularity_exe: str, out_dir: Path, model_dir: str, sample_id: str
+    singularity: str, out_dir: Path, model_dir: str, sample_id: str
 ) -> str:
     """Create command for doing fetal fraction estimation using Preface"""
     out_prefix = get_outprefix(out_dir, sample_id)
     predict_cmd = (
-        f"singularity exec {singularity_exe} Rscript /bin/PREFACE-0.1.1/PREFACE.R predict --infile"
+        f"{singularity} Rscript /bin/PREFACE-0.1.1/PREFACE.R predict --infile"
         f" {str(out_prefix)}.WCXpredict.preface_bins.bed --model {model_dir}/model.RData > "
         f"{str(out_prefix)}_bins.bed.PREFACE.txt"
     )
@@ -20,11 +20,11 @@ def get_preface_predict_cmd(
 
 
 def get_preface_model_cmd(
-    singularity_exe: str, config_path: Path, model_dir: str, settings: str,
+    singularity: str, config_path: Path, model_dir: str, settings: str,
 ) -> str:
     """Create command for doing fetal fraction estimation using Preface"""
     model_cmd = (
-        f"singularity exec {singularity_exe} Rscript /bin/PREFACE-0.1.1/PREFACE.R train --config "
+        f"{singularity} Rscript /bin/PREFACE-0.1.1/PREFACE.R train --config "
         f"{str(config_path)} --outdir {model_dir} {settings}"
     )
 
